Public Class frmSetup

    Public Sub Setup_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
    End Sub

    Private Sub btnAcceptVals_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnAcceptVals.Click
        ' check for entries in all setup boxes:
        If (txtExpID.Text = "" Or txtParticNum.Text = "" Or txtStimSetNum.Text = "") Then
            MessageBox.Show("Entries not complete") ' more rigor possible here

        Else : 
            ' create input file names:
            strExpIDstem = txtFilePath.Text + "\" + txtExpID.Text
            strPrmFileName = strExpIDstem + ".prm"
            strInstFileName = strExpIDstem + ".str"
            strStimFileName = strExpIDstem + "_" + txtStimSetNum.Text + ".sts"
            strRespFileName = strExpIDstem + "_" + txtParticNum.Text + ".rsp"

            ' read in values from parameter file:
            intNumTrials = CInt(ReadParam("TotalTrials"))
            intBlockSize = CInt(ReadParam("BlockSize"))
            intFrontFixed = CInt(ReadParam("FrontFixed"))
            intEndFixed = CInt(ReadParam("EndFixed"))
            intFontSize = CInt(ReadParam("FontSize"))
            intITI = CInt(ReadParam("ITInt"))
            intNumJudg = CInt(ReadParam("nJudg"))
            intNumSeq = CInt(ReadParam("nSeq"))

            ' read sequence-specific parameters:  
            For intSeqCount = 1 To intNumSeq
                strSeqNum = CStr(intSeqCount)
                intPreSeqIntvl(intSeqCount) = CInt(ReadParam("PreSeqInt" + strSeqNum))
                intFixIntvl(intSeqCount) = CInt(ReadParam("FixInt" + strSeqNum))
                intPostFixIntvl(intSeqCount) = CInt(ReadParam("PostFixInt" + strSeqNum))
                intStimIntvl(intSeqCount) = CInt(ReadParam("StimInt" + strSeqNum))
                intISIntvl(intSeqCount) = CInt(ReadParam("ISInt" + strSeqNum))
                intPostSeqIntvl(intSeqCount) = CInt(ReadParam("PostSeqInt" + strSeqNum))
                intSelfPaced(intSeqCount) = CInt(ReadParam("SelfPaced" + strSeqNum))
                intRtStim(intSeqCount) = CInt(ReadParam("RspStim" + strSeqNum))
            Next ' seq parameter set

            ' open StimSet File and read into StimList arrays, trial by trial:
            Dim objStimFile As New System.IO.StreamReader(strStimFileName)
            For intTrialCount = 1 To intNumTrials
                ' get stim identifier:
                strIdentifiers(intTrialCount) = objStimFile.ReadLine()
                ' get stim for each sequence, checking for flags:
                For intSeqCount = 1 To intNumSeq
                    strStimSeqLine = objStimFile.ReadLine()
                    intStimCount = 0
                    Do Until strStimSeqLine = "/" ' since "/" is used as stim separator, "//" will leave "/"
                        ' get next stim:
                        intStimCount = intStimCount + 1
                        strStim = ReadString(strStimSeqLine)
                        ' flag for EEG stim-specific start?
                        If Mid(strStim, 1, 1) = "#" Then
                            intSeqEEGStart(intTrialCount) = intSeqCount
                            intStimEEGStart(intTrialCount) = intStimCount
                            strStim = Mid(strStim, 2) ' trim off #
                        End If
                        ' flag for start of RT timing?
                        If Mid(strStim, 1, 1) = "@" Then
                            intSeqRtStart(intTrialCount) = intSeqCount
                            intStimRtStart(intTrialCount) = intStimCount
                            strStim = Mid(strStim, 2) ' trim off @
                        End If
                        ' flag to change stim color?
                        If Mid(strStim, 1, 1) = "*" Then
                            strStim = Mid(strStim, 2) ' trim off *, get color code:
                            intStimColor(intTrialCount, intSeqCount, intStimCount) = Mid(strStim, 1, 1)
                            strStim = Mid(strStim, 2) ' trim off color code
                        Else : intStimColor(intTrialCount, intSeqCount, intStimCount) = 1 ' for black
                        End If
                        ' store Stim in StimList:
                        strStimSeq(intTrialCount, intSeqCount, intStimCount) = strStim
                    Loop
                    intLastStim(intTrialCount, intSeqCount) = intStimCount
                Next ' Sequence
            Next ' TrialNum
            objStimFile.Close()
            objStimFile.Dispose()
            btnShowInstructions.Visible = True
            btnRunExp.Visible = True
        End If
    End Sub

    Private Sub btnShowInstructions_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnShowInstructions.Click
        Dim objInstFile As New System.IO.StreamReader(strInstFileName)
        txtInstructions.Visible = True
        txtInstructions.Text = objInstFile.ReadToEnd()
        objInstFile.Close()
        objInstFile.Dispose()
    End Sub

    Private Sub btnSelectPath_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnSelectPath.Click
        If fbdSelectPath.ShowDialog = Windows.Forms.DialogResult.OK Then
            txtFilePath.Text = fbdSelectPath.SelectedPath
        End If
    End Sub

    Public Function ReadParam(ByVal strTarget As String) As String
        Dim strParamValue As String
        Dim objPRMfile As New System.IO.StreamReader(strPrmFileName)
        strLine = objPRMfile.ReadLine()
        Do Until strLine Is Nothing
            If InStr(strLine, strTarget) > 0 Then
                strParamValue = Mid(strLine, Len(strTarget) + 2)
                Return strParamValue
            End If
            strLine = objPRMfile.ReadLine()
        Loop
        Return "-1"
    End Function

    Public Function ReadString(ByRef strStimSeqLine As String) As String
        Dim strTemp As String
        'get leftmost string up to first blank:
        strTemp = Mid(strStimSeqLine, 1, InStr(strStimSeqLine, "/") - 1)
        'trim that string from strLine and return:
        strStimSeqLine = Mid(strStimSeqLine, Len(strTemp) + 2)
        Return strTemp
    End Function

    Private Sub btnRunExp_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnRunExp.Click
        Permute()
        Me.Visible = False
        frmRunExp.Show()
    End Sub
    Public Sub Permute()
        Dim intItem As Integer
        ' seed order array:
        Randomize()
        For intTrialCount = 1 To intNumTrials
            intTrialOrder(intTrialCount, 2) = intTrialCount
        Next
        ' fix order of frontfixed trials:
        For intTrialCount = 1 To intFrontFixed
            intTrialOrder(intTrialCount, 1) = intTrialOrder(intTrialCount, 2)
        Next
        ' random permutation for trials from frontfixed+1 to endfixed-1:
        For intTrialCount = intNumTrials - intEndFixed To intFrontFixed + 1 Step -1
            intItem = intRandNum.Next(intFrontFixed + 1, intTrialCount)
            intTrialOrder(intTrialCount, 1) = intTrialOrder(intItem, 2)
            intTrialOrder(intItem, 2) = intTrialOrder(intTrialCount, 2)
        Next
        ' fix order for endfixed trials:
        For intTrialCount = intNumTrials - intEndFixed + 1 To intNumTrials
            intTrialOrder(intTrialCount, 1) = intTrialOrder(intTrialCount, 2)
        Next
    End Sub
End Class
